==> haskell-edit-distance-0.2.2.1-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-3jrilKvp6F39sg7SgTgifs
key:                  edit-distance-0.2.2.1-3jrilKvp6F39sg7SgTgifs
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  324d2d0d11ce7eec6b74b2a7851fa22f
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.0.2/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-3jrilKvp6F39sg7SgTgifs
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    random-1.2.1.1-HP1Jl4dlbgf891wCLsy6Z9

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-3PtEBWnslygHlkKRbH98CQ
key:                  edit-distance-0.2.2.1-3PtEBWnslygHlkKRbH98CQ
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  2e8d28e73951db87e115eeb44cb23480
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.0.2/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-3PtEBWnslygHlkKRbH98CQ
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    random-1.2.1.1-8Yy442tDgI9KXa8FjBISNx

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
